class ClassificationModel:
    def __init__(self):
        pass

    
    def predict_model(classifier, X):
        return classifier.predict(X)
    
    
    def evaluate_model(y_test, y_pred):
        from sklearn.metrics import confusion_matrix
        confusionMatrix = confusion_matrix(y_test, y_pred)
        
        return confusionMatrix

        


#  ____                        _
# / ___| _ __  _   _ _ __ __ _(_) ___
# \___ \| '_ \| | | | '__/ _` | |/ _ \
#  ___) | |_) | |_| | | | (_| | | (_) |
# |____/| .__/ \__, |_|  \__,_|_|\___/
#       |_|    |___/
#                 By Adriano P. Almeida

__title__ = 'spyraio'
__version__ = '0.0.9'
__description__ = 'Spyraio it\'s a Python package which contains some functions to lightning forecasting.'
__url__ = 'https://github.com/AdrianoPereira/spyraio'
__keywords__ = 'weather lightning nowcasting meteorology radar'
__author__ = 'Adriano P. Almeida'
__author_email__ = 'adriano.almeida@inpe.br'
__license__ = 'MIT'
__copyright__ = 'Copyright 2019 Adriano/INPE'


# -*- coding: utf-8 -*-
"""Preprocessing functions.
"""
import os
import pandas as pd
from sklearn.model_selection import train_test_split


def load_dataset(path, files):
    """Load dataframe.
    
    # Arguments
        `path`: a string containing the file directory.
        `files`: a list containing one or more file names.
    # Returns
        Return a concatenated dataframe from files.
    """
    
    dfs = [pd.read_csv(os.path.join(path, file)) for file in files]
    df = pd.concat(dfs, sort=False)
    
    return df


def filter_dataframe(df, filters):
    """Filter data frame.
    
    # Arguments
        `df`: a pandas dataframe.
        `filters`: a list containing the filters to apply to data frame.
    # Returns
        Return a filtered data frame.
    """
    
    df = df.query(filters)
    
    return df
    

def set_threshold(df=None, filters=[], samples=1):
    """Apply threshold to dataframe and merge.
    
    # Arguments
        `df`: a pandas dataframe.
        `filters`: a list containing the filters of threshold to apply to data 
        frame.
        `samples`: a percentage to the smallest filtered data frame.
    # Returns
        Return a single data frame with threshold.
    """
    
    dfs = []
    sizes = []
    for filter_ in filters:
        df = df.query(filter_)
        sizes.append(df.shape[0])
        dfs.append(df)
    
    samples *= 100
    samples = int((min(sizes)*samples)/100)
    
    dfs = [df.sample(samples) for df in dfs]
    
    df = pd.concat(dfs, sort=False).sample(samples*len(filters))
    
    return df


def train_and_test_split(X, y, test_size=0.2):
    """Slpit test and test dataset .
    
    # Arguments
        `X`: a list n-dimentional containing attributes values.
        `y`: Containg predict class values.
        `test_size (optional)`: size of dataset test (default: 20%).
        `samples`: a percentage to the smallest filtered data frame.
    # Returns
        Return the values of X_train, X_test, y_train and y_test.
    """
    
    X_train, X_test, y_train, y_test = train_test_split(X, y, test_size)
    return X_train, X_test, y_train, y_test
    
    
if __name__ == "__main__":
    df = load_dataset('./data/private', ['august.csv'])
    print(df)
    


from setuptools import setup
from setuptools import find_packages
import sys
import os
from codecs import open

here = os.path.abspath(os.path.dirname(__file__))

if sys.argv[-1]:
    if sys.argv[-1] == 'publish':
        os.system('python setup.py sdist bdist_wheel')
        os.system('twine upload dist/*')
        sys.exit()
    elif sys.argv[-1] == 'uninstall':
        os.system('rm -rf build')
        os.system('rm -rf dist')
        os.system('rm -rf spyraio.egg-info')

        os.system('twine upload dist/*')
        sys.exit()

requires = [
    'numpy',
    'matplotlib'
]

ABOUT = {}
with open(os.path.join(here, 'spyraio', '__about__.py'), 'r', 'utf-8') as f:
    exec(f.read(), ABOUT)

setup(
    name=ABOUT['__title__'],
    version=ABOUT['__version__'],
    url=ABOUT['__url__'],
    license=ABOUT['__license__'],
    author=ABOUT['__author__'],
    author_email=ABOUT['__author_email__'],
    keywords=ABOUT['__keywords__'],
    description=ABOUT['__description__'],
#    packages=['spyraio'],
    install_requires=requires,
    packages=find_packages())


from spyraio.classification.model import ModelClassification


class DecisionTreeClassifier(ModelClassification):
    def __init__(self):
        print('hello')
    
    
    def compute_model(X_train, y_train, criterion='gini', max_depth=None, 
                      max_leaf_nodes=None):
        from sklearn.tree import DecisionTreeClassifier

        classifier = DecisionTreeClassifier(criterion=criterion, 
                                            max_depth=max_depth,
                                            max_leaf_nodes=max_leaf_nodes)
        classifier.fit(X_train, y_train)

        return classifier
    